@@ -1,5 +1,5 @@
-use crate::math::{atan2, copysign, cos, hypot, sin};
-use std::f64::consts::FRAC_2_PI;
+use crate::math::{atan2, cos, hypot, sin};
+use alloc::vec::Vec;
 
 /// Geometric information.
 ///
@@ -55,10 +55,7 @@ impl GeoInfo {
     ///
     /// The `Efd` type can called with [`Efd::to`](crate::Efd::to).
     pub fn to(&self, rhs: &Self) -> Self {
-        let mut rot = rhs.rot - self.rot;
-        if sin(rot) < 0. {
-            rot += copysign(FRAC_2_PI, cos(rot));
-        }
+        let rot = rhs.rot - self.rot;
         let scale = rhs.scale / self.scale;
         let center_a = atan2(self.center[1], self.center[0]) + rot;
         let d = hypot(self.center[1], self.center[0]) * scale;
@@ -77,15 +74,14 @@ impl GeoInfo {
     /// This function rotates first, then translates.
     ///
     /// ```
-    /// # use efd::Efd;
-    /// # use efd::tests::{PATH, TARGET};
+    /// # use efd::{curve_diff, tests::{PATH, TARGET}, Efd};
     /// # let path = PATH;
     /// # let target = TARGET;
     /// # let efd = Efd::from_curve(path, None);
     /// # let path = efd.generate(target.len());
     /// # let geo = efd.geo;
     /// let path_new = geo.transform(&path);
-    /// # assert_eq!(path_new, TARGET);
+    /// # assert!(curve_diff(&path_new, TARGET) < 1e-12);
     /// ```
     ///
     /// The `Efd` type can called with [`Efd::transform`](crate::Efd::transform).
